
# Slot: open_world


if true, the the postconditions may be omitted in instance data, but it is valid for an inference engine to add these

URI: [linkml:open_world](https://w3id.org/linkml/open_world)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](Boolean.md)

## Parents


## Children


## Used by

 * [ClassRule](ClassRule.md)
